@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2016 IBM Corporation and others.
+ * Copyright (c) 2000, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -10,6 +10,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
+ *     George Suaridze <suag@1c.ru> (1C-Soft LLC) - Bug 560168
  *******************************************************************************/
 package org.eclipse.help.internal.search;
 
@@ -104,8 +105,7 @@ class IndexingOperation {
 		removeStaleDocuments(subMonitor.split(numRemoved), staleDocs);
 		checkCancelled(pm);
 		// 2. merge prebult plugin indexes and addjust
-		addNewDocuments(subMonitor.split(10 * numAdded), newDocs,
-				staleDocs.size() == 0);
+		addNewDocuments(subMonitor.split(10 * numAdded), newDocs, staleDocs.isEmpty());
 
 		pm.done();
 		BaseHelpSystem.getLocalSearchManager().clearSearchParticipants();
@@ -156,7 +156,7 @@ class IndexingOperation {
 		Map<String, String[]> docsToDelete = calculateNewToRemove(newDocs, prebuiltDocs);
 		SubMonitor subMonitor = SubMonitor.convert(pm, 10 * docsToIndex.size() + docsToDelete.size());
 		checkCancelled(pm);
-		addDocuments(subMonitor.split(10 * docsToIndex.size()), docsToIndex, docsToDelete.size() == 0);
+		addDocuments(subMonitor.split(10 * docsToIndex.size()), docsToIndex, docsToDelete.isEmpty());
 		checkCancelled(pm);
 		removeNewDocuments(subMonitor.split(docsToDelete.size()), docsToDelete);
 		pm.done();
@@ -195,7 +195,7 @@ class IndexingOperation {
 	 */
 	private void removeNewDocuments(IProgressMonitor pm, Map<String, String[]> docsToDelete)
 			throws IndexingException {
-		if (docsToDelete.size() == 0) {
+		if (docsToDelete.isEmpty()) {
 			return;
 		}
 		pm = new LazyProgressMonitor(pm);
@@ -227,7 +227,7 @@ class IndexingOperation {
 			checkCancelled(pm);
 			pm.worked(1);
 			if (multiStatus != null) {
-				HelpBasePlugin.logStatus(multiStatus);
+				Platform.getLog(getClass()).log(multiStatus);
 			}
 		}
 		if (!index.endRemoveDuplicatesBatch()) {
@@ -251,8 +251,7 @@ class IndexingOperation {
 					multiStatus = new MultiStatus(
 							HelpBasePlugin.PLUGIN_ID,
 							IStatus.ERROR,
-							"Help documentation could not be indexed completely.", //$NON-NLS-1$
-							null);
+							"Help documentation could not be indexed completely."); //$NON-NLS-1$
 				}
 				multiStatus.add(status);
 			}
@@ -260,7 +259,7 @@ class IndexingOperation {
 			pm.worked(1);
 		}
 		if (multiStatus != null) {
-			HelpBasePlugin.logStatus(multiStatus);
+			Platform.getLog(getClass()).log(multiStatus);
 		}
 		pm.subTask(HelpBaseResources.Writing_index);
 		if (!index.endAddBatch(addedDocs.size() > 0, lastOperation))
@@ -298,7 +297,7 @@ class IndexingOperation {
 				pm.worked(1);
 			}
 			if (multiStatus != null) {
-				HelpBasePlugin.logStatus(multiStatus);
+				Platform.getLog(getClass()).log(multiStatus);
 			}
 			if (!index.endDeleteBatch()) {
 				throw new IndexingException();
@@ -374,7 +373,8 @@ class IndexingOperation {
 			}
 			catch (Throwable t) {
 				// log the error and skip this participant
-				HelpBasePlugin.logError("Failed to get help search participant id for: " //$NON-NLS-1$
+				Platform.getLog(getClass()).error(
+						"Failed to get help search participant id for: " //$NON-NLS-1$
 						+ participant.getClass().getName() + "; skipping this one.", t); //$NON-NLS-1$
 				continue;
 			}
@@ -384,7 +384,8 @@ class IndexingOperation {
 			}
 			catch (Throwable t) {
 				// log the error and skip this participant
-				HelpBasePlugin.logError("Failed to retrieve documents from one of the help search participants: " //$NON-NLS-1$
+				Platform.getLog(getClass())
+						.error("Failed to retrieve documents from one of the help search participants: " //$NON-NLS-1$
 						+ participant.getClass().getName() + "; skipping this one.", t); //$NON-NLS-1$
 				continue;
 			}
@@ -463,7 +464,7 @@ class IndexingOperation {
 
 	private void add(String href, Set<String> hrefs) {
 		if (href != null
-				&& !href.equals("") && !href.startsWith("http://") && !href.startsWith("https://")) //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$
+				&& !href.isEmpty() && !href.startsWith("http://") && !href.startsWith("https://")) //$NON-NLS-1$ //$NON-NLS-2$
 			hrefs.add(href);
 	}
 
@@ -518,7 +519,7 @@ class IndexingOperation {
 						}
 						else {
 							String msg = "Element \"index\" in extension of \"org.eclipse.help.toc\" must specify a \"path\" attribute (plug-in: " + pluginId + ")"; //$NON-NLS-1$ //$NON-NLS-2$
-							HelpBasePlugin.logError(msg, null);
+							Platform.getLog(getClass()).error(msg, null);
 						}
 					}
 				}
