@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2019 IBM Corporation and others.
+ * Copyright (c) 2000, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -10,11 +10,11 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
+ *     George Suaridze <suag@1c.ru> (1C-Soft LLC) - Bug 560168
  *******************************************************************************/
 package org.eclipse.help.internal.search.federated;
 
 import java.util.ArrayList;
-import java.util.Collections;
 import java.util.List;
 
 import org.eclipse.core.runtime.*;
@@ -54,7 +54,7 @@ public class LocalHelp implements ISearchEngine2 {
 					query = modQuery;
 			}
 		}
-		Collections.sort(altList);
+		altList.sort(null);
 
 
 		SearchQuery searchQuery = new SearchQuery();
@@ -151,7 +151,9 @@ public class LocalHelp implements ISearchEngine2 {
 			return participant.open(id);
 		}
 		catch (Throwable t) {
-			HelpBasePlugin.logError("Error occured in search participant trying to open document with id: " + id + ", participant: " + participant.getClass().getName(), t); //$NON-NLS-1$ //$NON-NLS-2$
+			Platform.getLog(getClass())
+					.error("Error occured in search participant trying to open document with id: " + id //$NON-NLS-1$
+							+ ", participant: " + participant.getClass().getName(), t); //$NON-NLS-1$
 			return false;
 		}
 	}
