@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2017 IBM Corporation and others.
+ * Copyright (c) 2000, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -10,13 +10,15 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
+ *     George Suaridze <suag@1c.ru> (1C-Soft LLC) - Bug 560168
  *******************************************************************************/
 package org.eclipse.help.ui.internal.views;
 
-import java.io.UnsupportedEncodingException;
 import java.net.MalformedURLException;
 import java.net.URL;
 import java.net.URLDecoder;
+import java.nio.charset.StandardCharsets;
+import java.text.Collator;
 import java.util.ArrayList;
 import java.util.HashMap;
 import java.util.Iterator;
@@ -100,10 +102,7 @@ import org.eclipse.ui.forms.widgets.FormToolkit;
 import org.eclipse.ui.forms.widgets.ILayoutExtension;
 import org.eclipse.ui.forms.widgets.ScrolledForm;
 
-import com.ibm.icu.text.Collator;
-
-public class ReusableHelpPart implements IHelpUIConstants,
-		IActivityManagerListener {
+public class ReusableHelpPart implements IHelpUIConstants, IActivityManagerListener {
 	public static final int ALL_TOPICS = 1 << 1;
 
 	public static final int CONTEXT_HELP = 1 << 2;
@@ -193,7 +192,7 @@ public class ReusableHelpPart implements IHelpUIConstants,
 
 		@Override
 		public void run() {
-			BusyIndicator.showWhile(getControl().getDisplay(), () -> busyRun());
+			BusyIndicator.showWhile(getControl().getDisplay(), this::busyRun);
 		}
 
 		protected abstract void busyRun();
@@ -314,6 +313,8 @@ public class ReusableHelpPart implements IHelpUIConstants,
 
 		private int nflexible;
 
+		private boolean updateActionBars = true;
+
 		public HelpPartPage(String id, String text) {
 			this.id = id;
 			this.text = text;
@@ -531,7 +532,10 @@ public class ReusableHelpPart implements IHelpUIConstants,
 					bars.activate();
 				else
 					bars.deactivate();
-				bars.updateActionBars();
+
+				if (this.updateActionBars) {
+					bars.updateActionBars();
+				}
 			} else {
 				((SubToolBarManager) subToolBarManager).setVisible(visible);
 				if (subMenuManager != null) {
@@ -700,8 +704,7 @@ public class ReusableHelpPart implements IHelpUIConstants,
 	class UAFilter extends ViewerFilter {
 
 		@Override
-		public boolean select(Viewer viewer, Object parentElement,
-				Object element) {
+		public boolean select(Viewer viewer, Object parentElement, Object element) {
 			return !UAContentFilter.isFiltered(element, HelpEvaluationContext.getContext());
 		}
 	}
@@ -715,8 +718,7 @@ public class ReusableHelpPart implements IHelpUIConstants,
 		history = new ReusableHelpPartHistory();
 		this.style = style;
 		ensureHelpIndexed();
-		PlatformUI.getWorkbench().getActivitySupport().getActivityManager()
-				.addActivityManagerListener(this);
+		PlatformUI.getWorkbench().getActivitySupport().getActivityManager().addActivityManagerListener(this);
 	}
 
 	/*
@@ -775,8 +777,8 @@ public class ReusableHelpPart implements IHelpUIConstants,
 		pages = new ArrayList<>();
 		// federated search page
 		HelpPartPage page = new HelpPartPage(HV_FSEARCH_PAGE,
-				Messages.ReusableHelpPart_searchPage_name,
-				IHelpUIConstants.IMAGE_HELP_SEARCH);
+	 			Messages.ReusableHelpPart_searchPage_name,
+	 			IHelpUIConstants.IMAGE_HELP_SEARCH);
 		page.setVerticalSpacing(0);
 		page.addPart(HV_SEE_ALSO, false);
 		page.addPart(HV_MISSING_CONTENT, false);
@@ -1013,7 +1015,7 @@ public class ReusableHelpPart implements IHelpUIConstants,
 		mform.getForm().setDelayedReflow(false);
 		toolkit.decorateFormHeading(mform.getForm().getForm());
 		MenuManager manager = new MenuManager();
-		IMenuListener listener = manager1 -> contextMenuAboutToShow(manager1);
+		IMenuListener listener = this::contextMenuAboutToShow;
 		manager.setRemoveAllWhenShown(true);
 		manager.addMenuListener(listener);
 		Menu contextMenu = manager.createContextMenu(form.getForm());
@@ -1069,8 +1071,14 @@ public class ReusableHelpPart implements IHelpUIConstants,
 			return false;
 		if (oldPage != null) {
 			oldPage.stop();
+			oldPage.updateActionBars = false;
 			oldPage.setVisible(false);
+			oldPage.updateActionBars = true;
 		}
+
+		newPage.updateActionBars = false;
+		newPage.setVisible(true);
+		newPage.updateActionBars = true;
 		mform.getForm().setText(null); //(newPage.getText());
 		mform.getForm().getForm().setSeparatorVisible(newPage.getText()!=null);
 		Image newImage=null;
@@ -1078,7 +1086,7 @@ public class ReusableHelpPart implements IHelpUIConstants,
 		//if (iconId != null)
 			//newImage = HelpUIResources.getImage(iconId);
 		mform.getForm().setImage(newImage);
-		newPage.setVisible(true);
+
 		toolBarManager.update(true);
 		currentPage = newPage;
 		if (mform.isStale())
@@ -1092,6 +1100,7 @@ public class ReusableHelpPart implements IHelpUIConstants,
 			}
 			updateNavigation();
 		}
+
 		return true;
 	}
 
@@ -1127,8 +1136,8 @@ public class ReusableHelpPart implements IHelpUIConstants,
 	}
 
 	public boolean isMonitoringContextHelp() {
-		return currentPage != null
-				&& currentPage.getId().equals(HV_CONTEXT_HELP_PAGE);
+		return currentPage != null && (currentPage.getId().equals(HV_CONTEXT_HELP_PAGE)
+				|| currentPage.getId().equals(HV_BROWSER_PAGE));
 	}
 
 	public Control getControl() {
@@ -1186,8 +1195,22 @@ public class ReusableHelpPart implements IHelpUIConstants,
 	 * @param isExplicitRequest is true if this is the result of a direct user request such as
 	 * pressing F1 and false if it is in response to a focus change listener
 	 */
-	public void update(IContextProvider provider, IContext context, IWorkbenchPart part,
-			Control control, boolean isExplicitRequest) {
+	public void update(IContextProvider provider, IContext context, IWorkbenchPart part, Control control,
+			boolean isExplicitRequest) {
+		IContext realContext = context;
+		if (provider != null) {
+			realContext = provider.getContext(control);
+		}
+		if (realContext != null) {
+			String contextText = realContext.getText();
+			IHelpResource[] topics = realContext.getRelatedTopics();
+			if (contextText == null && topics.length == 1) {
+				showURL(topics[0].getHref());
+				return;
+			}
+		}
+		// Ensure that context help is currently showing
+		showPage(IHelpUIConstants.HV_CONTEXT_HELP_PAGE);
 		mform.setInput(new ContextHelpProviderInput(provider, context, control, part, isExplicitRequest));
 	}
 
@@ -1336,7 +1359,7 @@ public class ReusableHelpPart implements IHelpUIConstants,
 				PlatformUI.getWorkbench().getHelpSystem().displayHelpResource(aurl);
 
 			} catch (Exception e) {
-				HelpUIPlugin.logError("Error opening browser", e); //$NON-NLS-1$
+				Platform.getLog(getClass()).error("Error opening browser", e); //$NON-NLS-1$
 			}
 		}
 	}
@@ -1572,10 +1595,6 @@ public class ReusableHelpPart implements IHelpUIConstants,
 		}
 	}
 
-	/*
-	 * private void doOpen(Object target) { String href = getHref(target); if
-	 * (href != null) showURL(href, getShowDocumentsInPlace()); }
-	 */
 
 	private void doOpen(Object target, boolean replace) {
 		String href = getHref(target);
@@ -1586,7 +1605,6 @@ public class ReusableHelpPart implements IHelpUIConstants,
 	private void doOpenInHelp(Object target) {
 		String href = getHref(target);
 		if (href != null)
-			// WorkbenchHelp.displayHelpResource(href);
 			showURL(href, false);
 	}
 
@@ -1635,10 +1653,7 @@ public class ReusableHelpPart implements IHelpUIConstants,
 			if (href != null && href.startsWith("__")) //$NON-NLS-1$
 				href = null;
 			if (href != null) {
-				try {
-					href = URLDecoder.decode(href, "UTF-8"); //$NON-NLS-1$
-				} catch (UnsupportedEncodingException ex) {
-				}
+				href = URLDecoder.decode(href, StandardCharsets.UTF_8);
 				// Next line unnecessary following fix for Bug 78746
 				//href = href.replaceAll("&", "&&"); //$NON-NLS-1$ //$NON-NLS-2$
 			}
@@ -1754,7 +1769,7 @@ public class ReusableHelpPart implements IHelpUIConstants,
 		return engineManager;
 	}
 
-	static public int getDefaultStyle() {
+	public static int getDefaultStyle() {
 		int style = ALL_TOPICS | CONTEXT_HELP | SEARCH;
 		if (ProductPreferences.getBoolean(HelpBasePlugin.getDefault(), "indexView")) { //$NON-NLS-1$
 			style |= INDEX;
@@ -1796,4 +1811,3 @@ public class ReusableHelpPart implements IHelpUIConstants,
 		mcPart.updateStatus();
 	}
 }
-
