@@ -17,7 +17,7 @@ package org.eclipse.ua.tests.doc.internal.actions;
 import java.util.ArrayList;
 import java.util.List;
 
-import org.eclipse.help.internal.HelpPlugin;
+import org.eclipse.core.runtime.Platform;
 import org.eclipse.help.internal.toc.Toc;
 import org.eclipse.help.internal.validation.TocValidator;
 import org.eclipse.help.internal.validation.TocValidator.BrokenLink;
@@ -33,7 +33,7 @@ public class CheckTocAction implements IWorkbenchWindowActionDelegate {
 	public static List<BrokenLink> errors = new ArrayList<>();
 
 	public static void showErrors() {
-		if (errors.size() == 0) {
+		if (errors.isEmpty()) {
 			reportStatus("No errors detected in load");
 		}
 		for (int i = 0; i < errors.size(); i++) {
@@ -43,7 +43,7 @@ public class CheckTocAction implements IWorkbenchWindowActionDelegate {
 	}
 
 	private static void reportStatus(String errorMessage) {
-		HelpPlugin.logWarning(errorMessage);
+		Platform.getLog(CheckTocAction.class).warn(errorMessage);
 	}
 
 
